@@ -10,7 +10,7 @@ use Error::Pure qw(err);
 use PYX::Parser;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -30,7 +30,7 @@ sub new {
 	set_params($self, @params);
 
 	# PYX::Parser object.
-	$self->{'pyx_parser'} = PYX::Parser->new(
+	$self->{'_pyx_parser'} = PYX::Parser->new(
 		'callbacks' => {
 			'end_element' => \&_end_element,
 			'start_element' => \&_start_element,
@@ -51,21 +51,21 @@ sub new {
 # Parse pyx text or array of pyx text.
 sub parse {
 	my ($self, $pyx, $out) = @_;
-	$self->{'pyx_parser'}->parse($pyx, $out);
+	$self->{'_pyx_parser'}->parse($pyx, $out);
 	return;
 }
 
 # Parse file with pyx text.
 sub parse_file {
 	my ($self, $file, $out) = @_;
-	$self->{'pyx_parser'}->parse_file($file, $out);
+	$self->{'_pyx_parser'}->parse_file($file, $out);
 	return;
 }
 
 # Parse from handler.
 sub parse_handler {
 	my ($self, $input_file_handler, $out) = @_;
-	$self->{'pyx_parser'}->parse_handler($input_file_handler, $out);
+	$self->{'_pyx_parser'}->parse_handler($input_file_handler, $out);
 	return;
 }
 
@@ -73,7 +73,6 @@ sub parse_handler {
 sub _end_element {
 	my ($pyx_parser_obj, $elem) = @_;
 	my $stack_ar = $pyx_parser_obj->{'non_parser_options'}->{'stack'};
-	my $out = $pyx_parser_obj->{'output_handler'};
 	if ($stack_ar->[-1] eq $elem) {
 		pop @{$stack_ar};
 	} elsif ($pyx_parser_obj->{'non_parser_options'}->{'bad_end'}) {
@@ -83,6 +82,7 @@ sub _end_element {
 	if ($pyx_parser_obj->{'non_parser_options'}->{'verbose'}
 		&& @{$stack_ar} > 0) {
 
+		my $out = $pyx_parser_obj->{'output_handler'};
 		print {$out} join('/', @{$stack_ar}), "\n";
 	}
 	return;
@@ -310,7 +310,16 @@ L<PYX::Parser>.
 
 =head1 SEE ALSO
 
-L<App::PYX::Stack>.
+L<PYX>,
+L<PYX::GraphViz>,
+L<PYX::Hist>,
+L<PYX::Parser>,
+L<PYX::Utils>,
+L<Task::PYX>.
+
+=head1 REPOSITORY
+
+L<https://github.com/tupinek/PYX-Stack>
 
 =head1 AUTHOR
 
@@ -325,6 +334,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
